@@ -1025,6 +1025,9 @@ document_loaded (GeditDocument *document,
 				   mime);
 		g_free (mime);
 
+		/* Scroll to the cursor when the document is loaded */
+		gedit_view_scroll_to_cursor (GEDIT_VIEW (tab->priv->view));
+
 		all_documents = gedit_app_get_documents (gedit_app_get_default ());
 
 		for (l = all_documents; l != NULL; l = g_list_next (l))
@@ -2321,17 +2324,18 @@ done_printing_cb (GeditPrintJob       *job,
 
 	// TODO: check status and error
 
-	/* Save the print settings */ 
+	/* Save the print settings and the page setup */ 
 	if (result ==  GEDIT_PRINT_JOB_RESULT_OK)
 	{
 		GeditDocument *doc;
 		GtkPrintSettings *settings;
+		GtkPageSetup *page_setup;
 
 		doc = gedit_tab_get_document (tab);
 
 		settings = gedit_print_job_get_print_settings (job);
 
-		/* remember them for this document */
+		/* remember settings for this document */
 		g_object_set_data_full (G_OBJECT (doc),
 					GEDIT_PRINT_SETTINGS_KEY,
 					g_object_ref (settings),
@@ -2340,6 +2344,18 @@ done_printing_cb (GeditPrintJob       *job,
 		/* make them the default */
 		_gedit_app_set_default_print_settings (gedit_app_get_default (),
 						       settings);
+
+		page_setup = gedit_print_job_get_page_setup (job);
+
+		/* remember page setup for this document */
+		g_object_set_data_full (G_OBJECT (doc),
+					GEDIT_PAGE_SETUP_KEY,
+					g_object_ref (page_setup),
+					(GDestroyNotify)g_object_unref);
+
+		/* make it the default */
+		_gedit_app_set_default_page_setup (gedit_app_get_default (),
+						   page_setup);
 	}
 
 #if 0
@@ -2504,6 +2520,8 @@ show_printing_message_area (GeditTab *tab, gboolean preview)
 	set_message_area (tab, area);
 }
 
+#if !GTK_CHECK_VERSION (2, 17, 4)
+
 static void
 page_setup_done_cb (GtkPageSetup *setup,
 		    GeditTab     *tab)
@@ -2546,6 +2564,8 @@ _gedit_tab_page_setup (GeditTab *tab)
 	/* CHECK: should we unref setup and settings? */
 }
 
+#endif
+
 static void
 gedit_tab_print_or_print_preview (GeditTab                *tab,
 				  GtkPrintOperationAction  print_action)
