@@ -47,15 +47,9 @@ class ToolLibrary(Singleton):
 
         # self.locations[0] is where we save the custom scripts
         if platform.platform() == 'Windows':
-            toolsdir = os.path.expanduser('~/gedit/tools')
+            self.locations.insert(0, os.path.expanduser('~/gedit/tools'))
         else:
-            userdir = os.getenv('GNOME22_USER_DIR')
-            if userdir:
-                toolsdir = os.path.join(userdir, 'gedit/tools')
-            else:
-                toolsdir = os.path.expanduser('~/.gnome2/gedit/tools')
-
-        self.locations.insert(0, toolsdir);
+            self.locations.insert(0, os.path.expanduser('~/.gnome2/gedit/tools'))
 
         if not os.path.isdir(self.locations[0]):
             os.makedirs(self.locations[0])
@@ -77,13 +71,8 @@ class ToolLibrary(Singleton):
     # created. It imports eventual tools that have been saved in the old XML
     # storage file.
     def import_old_xml_store(self):
-        import ElementTree as et
-        userdir = os.getenv('GNOME22_USER_DIR')
-        if userdir:
-            filename = os.path.join(userdir, 'gedit/gedit-tools.xml')
-        else:
-            filename = os.path.expanduser('~/.gnome2/gedit/gedit-tools.xml')
-
+        import xml.etree.ElementTree as et
+        filename = os.path.expanduser('~/.gnome2/gedit/gedit-tools.xml')
         if not os.path.isfile(filename):
             return
 
